package com.qianhe.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.qianhe.mapper.SjGfjsDxjczMapper;
import com.qianhe.domain.SjGfjsDxjcz;
import com.qianhe.service.ISjGfjsDxjczService;

/**
 * 单项基础值Service业务层处理
 *
 * @author qianhe
 * @date 2025-08-15
 */
@Service
public class SjGfjsDxjczServiceImpl implements ISjGfjsDxjczService
{
    @Autowired
    private SjGfjsDxjczMapper sjGfjsDxjczMapper;

    /**
     * 查询单项基础值
     *
     * @param id 单项基础值主键
     * @return 单项基础值
     */
    @Override
    public SjGfjsDxjcz selectSjGfjsDxjczById(Long id)
    {
        return sjGfjsDxjczMapper.selectSjGfjsDxjczById(id);
    }

    /**
     * 查询单项基础值列表
     *
     * @param sjGfjsDxjcz 单项基础值
     * @return 单项基础值
     */
    @Override
    public List<SjGfjsDxjcz> selectSjGfjsDxjczList(SjGfjsDxjcz sjGfjsDxjcz)
    {
        return sjGfjsDxjczMapper.selectSjGfjsDxjczList(sjGfjsDxjcz);
    }

    /**
     * 新增单项基础值
     *
     * @param sjGfjsDxjcz 单项基础值
     * @return 结果
     */
    @Override
    public int insertSjGfjsDxjcz(SjGfjsDxjcz sjGfjsDxjcz)
    {
        return sjGfjsDxjczMapper.insertSjGfjsDxjcz(sjGfjsDxjcz);
    }

    /**
     * 修改单项基础值
     *
     * @param sjGfjsDxjcz 单项基础值
     * @return 结果
     */
    @Override
    public int updateSjGfjsDxjcz(SjGfjsDxjcz sjGfjsDxjcz)
    {
        return sjGfjsDxjczMapper.updateSjGfjsDxjcz(sjGfjsDxjcz);
    }

    /**
     * 批量删除单项基础值
     *
     * @param ids 需要删除的单项基础值主键
     * @return 结果
     */
    @Override
    public int deleteSjGfjsDxjczByIds(Long[] ids)
    {
        return sjGfjsDxjczMapper.deleteSjGfjsDxjczByIds(ids);
    }

    /**
     * 删除单项基础值信息
     *
     * @param id 单项基础值主键
     * @return 结果
     */
    @Override
    public int deleteSjGfjsDxjczById(Long id)
    {
        return sjGfjsDxjczMapper.deleteSjGfjsDxjczById(id);
    }
}
